ChordBase

Struct ChordBase 

pub struct ChordBase<R, T = <R as RawChord>::Elem>
where R: ?Sized + RawChord<Elem = T>,
{ /* private fields */ }
The ChordBase implementation is designed to be a generic container allowing

Implementations

Source

impl<S, T> ChordBase<S, T>
where S: RawChord<Elem = T>,

pub const fn new(repr: S) -> Self

creates a new ChordBase instance from a given chord representation.

pub const fn data(&self) -> &S

returns a reference to the underlying chord representation.

pub const fn data_mut(&mut self) -> &mut S

returns a mutable reference to the underlying chord representation.

pub fn len(&self) -> usize

returns the number of elements in the chord representation.

pub fn is_empty(&self) -> bool

returns true if the chord contains no elements