#[non_exhaustive]pub enum IntervalQuality {
Augmented(PhantomData<Augmented>),
Diminished(PhantomData<Diminished>),
Major(PhantomData<Major>),
Minor(PhantomData<Minor>),
Perfect(PhantomData<Perfect>),
}Expand description
This enum provides a more streamlined means of working with the implemented Quality types. Primarily, it provides simple creation routines for otherwise unitializable types.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Augmented(PhantomData<Augmented>)
Diminished(PhantomData<Diminished>)
Major(PhantomData<Major>)
Minor(PhantomData<Minor>)
Perfect(PhantomData<Perfect>)
Implementations
Sourceimpl IntervalQuality
impl IntervalQuality
Sourcepub const fn is_augmented(&self) -> bool
pub const fn is_augmented(&self) -> bool
Returns true if the enum is IntervalQuality::Augmented otherwise false
Sourcepub const fn is_diminished(&self) -> bool
pub const fn is_diminished(&self) -> bool
Returns true if the enum is IntervalQuality::Diminished otherwise false
Sourcepub const fn is_major(&self) -> bool
pub const fn is_major(&self) -> bool
Returns true if the enum is IntervalQuality::Major otherwise false
Sourcepub const fn is_minor(&self) -> bool
pub const fn is_minor(&self) -> bool
Returns true if the enum is IntervalQuality::Minor otherwise false
Sourcepub const fn is_perfect(&self) -> bool
pub const fn is_perfect(&self) -> bool
Returns true if the enum is IntervalQuality::Perfect otherwise false